import { AdRecord } from "../records/ad.records";
import { AdEntity } from "../types";
import { pool } from "../utlis/db";

const defaultObj ={
    name: 'Test Name',
    description: 'pieski małe',
    url: 'https//mega.pl',
    price: 0,
    lat: 53.19,
    lon: 18.00
};

afterAll(async() => {
    await pool.end()
});



test('AdRecord return data from database for one entry', async() =>{

const ad = await AdRecord.getOne('abc');

// console.log(ad);

expect(ad).toBeDefined();
expect(ad.id).toBe('abc')
expect(ad.name).toBe('Testa');

});

test('AdRecord.getOne returns null from database for unexisting entry.', async()=> {
    const ad = await AdRecord.getOne('---');
    expect(ad).toBeNull();
});

test('AdRecord.findAll returns array of found entries', async()=> {

    const ads = await AdRecord.findAll('');

    expect(ads).not.toEqual([]);
    expect(ads[0].id).toBeDefined();
});

test ('AdRecord.findAll returns array of found entries when searching for"a".', async()=>{
    const ads=await AdRecord.findAll('e');
    expect(ads).not.toEqual([]);
    expect(ads[0].id).toBeDefined();
});


test('AdRecord.findAll returns array when searching for something that does not exit', async()=> {

    const ads = await AdRecord.findAll('------------');

    expect(ads).toEqual([]);
});

test('AdRecord.finallAll returns smalle amout of data', async() => {

    const ads = await AdRecord.findAll('');
    expect((ads[0] as AdEntity).price).toBeUndefined();
    expect((ads[0] as AdEntity).description).toBeUndefined();
});


test('AdRecord.insert returns ne UUID', async() => {

    const ad = new AdRecord(defaultObj)
    await ad.insert();
    expect(ad.id).toBeDefined();
    expect(typeof ad.id).toBe('string');
});

test('AdRecord.insert inserts data to database', async() => {

    const ad = new AdRecord(defaultObj);
    await ad.insert();
    
    const foundAd = await AdRecord.getOne(ad.id);

    expect(foundAd).toBeDefined();
    expect(foundAd).not.toBeNull();
    expect(foundAd.id).toBe(ad.id);

});
